@@ -11,8 +11,9 @@ from opps.core.models import Publishable, BaseBox
 
 try:
     OPPS_APPS = tuple([(u"{0}.{1}".format(
-        app._meta.app_label, app._meta.object_name), u"{0} - {1}".format(
-            app._meta.app_label, app._meta.object_name))
+        app._meta.app_label, app._meta.object_name
+    ), u"{0} - {1}".format(
+        app._meta.app_label, app._meta.object_name))
         for app in models.get_models() if 'opps.' in app.__module__])
 except ImportError:
     OPPS_APPS = tuple([])
