@@ -28,7 +28,7 @@ VALIGN_CHOICES = (
 def get_file_path(instance, filename):
     ext = filename.split('.')[-1]
     filename = u"{0}-{1}.{2}".format(random.getrandbits(32),
-                                     instance.slug, ext)
+                                     instance.slug[:100], ext)
     d = datetime.now()
     folder = "images/{0}".format(d.strftime("%Y/%m/%d/"))
     return os.path.join(folder, filename)
@@ -114,9 +114,10 @@ class Image(Publishable, Cropping):
     tags = TaggableManager(blank=True, through=TaggedImage,
                            verbose_name=u'Tags')
 
-    source = models.ForeignKey('sources.Source', null=True, blank=True)
+    source = models.ForeignKey('sources.Source', verbose_name=_(u'Source'),
+                               null=True, blank=True)
 
-    class META:
+    class Meta:
         verbose_name = _('Image')
         verbose_name_plural = _('Images')
         unique_together = ['site', 'slug']
